This is the mail archive of the libc-ports@sources.redhat.com mailing list for the libc-ports project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

MIPS epoll_create update


I've applied this patch to make the MIPS sys/epoll.h conform to changes to 
the generic version to define epoll_create1 (without a SIZE parameter) 
instead of epoll_create2.

I was initially confused by the change

2008-08-01  Ulrich Drepper  <drepper@redhat.com>

        * sysdeps/unix/sysv/linux/Versions: Fix changes due to old patch for
        new epoll_create1 interface.
        * sysdeps/unix/sysv/linux/syscalls.list: Likewise.
        * sysdeps/unix/sysv/linux/sys/epoll.h: Likewise.
        * sysdeps/unix/sysv/linux/x86_64/sys/epoll.h: Likewise.

not touching the SPARC or Alpha versions of the header, but as far as I 
can tell there are no target differences regarding these syscalls in the 
kernel (though not all targets have the syscall wired up yet), should be 
no target differences in the glibc API, and glibc will never export a 
function epoll_create2 anyway given the Versions change.  Thus, the 
omission of those target versions, and of the comment "/* Flags to be 
passed to epoll_create2.  */" in all versions, in that libc patch appears 
simply to be an oversight.

Index: ChangeLog.mips
===================================================================
RCS file: /cvs/glibc/ports/ChangeLog.mips,v
retrieving revision 1.60
diff -u -r1.60 ChangeLog.mips
--- ChangeLog.mips	19 Aug 2008 16:12:34 -0000	1.60
+++ ChangeLog.mips	19 Aug 2008 16:51:38 -0000
@@ -1,5 +1,10 @@
 2008-08-19  Joseph Myers  <joseph@codesourcery.com>
 
+	* sysdeps/unix/sysv/linux/mips/sys/epoll.h: Change epoll_create2
+	to epoll_create1.
+
+2008-08-19  Joseph Myers  <joseph@codesourcery.com>
+
 	* sysdeps/unix/sysv/linux/mips/bits/socket.h: Define SOCK_CLOEXEC,
 	SOCK_NONBLOCK, PF_ISDN and AF_ISDN.
 	* sysdeps/unix/sysv/linux/mips/sys/epoll.h: New file.
Index: sysdeps/unix/sysv/linux/mips/sys/epoll.h
===================================================================
RCS file: /cvs/glibc/ports/sysdeps/unix/sysv/linux/mips/sys/epoll.h,v
retrieving revision 1.1
diff -u -r1.1 epoll.h
--- sysdeps/unix/sysv/linux/mips/sys/epoll.h	19 Aug 2008 16:12:35 -0000	1.1
+++ sysdeps/unix/sysv/linux/mips/sys/epoll.h	19 Aug 2008 16:51:38 -0000
@@ -31,7 +31,7 @@
 #endif
 
 
 /* Flags to be passed to epoll_create2.  */
 enum
   {
     EPOLL_CLOEXEC = 02000000,
@@ -101,8 +101,9 @@
    returned by epoll_create() should be closed with close().  */
 extern int epoll_create (int __size) __THROW;
 
-/* Same as epoll_create but with an additional FLAGS parameter.  */
-extern int epoll_create2 (int __size, int __flags) __THROW;
+/* Same as epoll_create but with an FLAGS parameter.  The unused SIZE
+   parameter has been dropped.  */
+extern int epoll_create1 (int __flags) __THROW;
 
 
 /* Manipulate an epoll instance "epfd". Returns 0 in case of success,
@@ -31,7 +31,7 @@
 
 
-/* Flags to be passed to epoll_create2.  */
+/* Flags to be passed to epoll_create1.  */
 enum
   {

-- 
Joseph S. Myers
joseph@codesourcery.com


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]